// ignore_for_file: library_private_types_in_public_api, no_logic_in_create_state, use_key_in_widget_constructors, prefer_const_constructors_in_immutables

import 'package:awesome_dialog/awesome_dialog.dart';
import 'package:flutter/scheduler.dart';
import 'package:progamification/src/components/leaderboard_info.dart';
import 'package:progamification/src/controllers/leader_board.dart';
import 'package:get/get.dart';
import 'package:flutter/material.dart';
import 'package:progamification/src/services/gamification.service.dart';
import 'package:progamification/src/services/leaderboard.service.dart';

class LeaderBoard extends StatefulWidget {
  final String clientId;
  final String clientSecret;
  final String userId;
  final String applicationId;

  LeaderBoard(
      {required this.clientId,
      required this.clientSecret,
      required this.userId,
      required this.applicationId});
  @override
  _LeaderBoardState createState() =>
      _LeaderBoardState(clientId, clientSecret, userId, applicationId);
}

class _LeaderBoardState extends State<LeaderBoard> {
  late String clientId;
  late String clientSecret;
  late String userId;
  late String applicationId;

  late bool isGamificationVisible = false;
  bool _isInitStateComplete = false;
  _LeaderBoardState(
      this.clientId, this.clientSecret, this.userId, this.applicationId);
  late GamificationService gamificationService;
  late LeaderBoardService leaderBoardService;

  late LeaderBoardController leaderBoardController;
  // bool isGamificationEnabled = false;

  @override
  void initState() {
    super.initState();
    SchedulerBinding.instance.addPostFrameCallback((_) {
      setState(() {
        _isInitStateComplete = true;
      });
    });
    initGame();
  }

  Future<void> initGame() async {
    Get.put<GamificationService>(GamificationService(), permanent: true);
    gamificationService = Get.find();

    isGamificationVisible = await gamificationService.init(
        clientId, clientSecret, userId, applicationId);
    leaderBoardService = Get.find();
    leaderBoardController = Get.find<LeaderBoardController>();
    if (isGamificationVisible) {
      await getData(userId, applicationId);
      await leaderBoardController.getRewards(userId, applicationId);
    }
  }

  Future<void> getData(String userId, String applicationId) async {
    try {
      await leaderBoardService
          .getLeaderBoard(userId, applicationId)
          .then(leaderBoardController.setData)
          .then((value) => isGamificationVisible = true);
    } catch (e) {
      setState(() {
        isGamificationVisible = false;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return _isInitStateComplete && isGamificationVisible
        ? Container(
            padding: const EdgeInsets.only(left: 0, right: 0),
            decoration: BoxDecoration(
              borderRadius: BorderRadius.circular(10),
            ),
            child: Row(
              children: [
                InkWell(
                  onTap: (() async {
                    await leaderBoardController.getData(userId, applicationId);
                    await leaderBoardController.getRewards(
                        userId, applicationId);
                    AwesomeDialog(
                      context: context,
                      dialogType: DialogType.noHeader,
                      headerAnimationLoop: false,
                      animType: AnimType.topSlide,
                      showCloseIcon: false,
                      btnCancelOnPress: () {},
                      btnOkOnPress: () {},
                      btnOk: Container(),
                      btnCancel: Container(),
                      body: const LeaderboardInfo(),
                    ).show();
                  }),
                  child: Container(
                    margin: const EdgeInsets.all(2),
                    child: const Icon(
                      Icons.sports_score_outlined,
                      color: Colors.black,
                    ),
                  ),
                ),
              ],
            ),
          )
        : Container();
  }
}
